summaryrefslogtreecommitdiffstats
path: root/src/inkscape-application.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/inkscape-application.cpp')
-rw-r--r--src/inkscape-application.cpp6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/inkscape-application.cpp b/src/inkscape-application.cpp
index 1ba4cd0b6..97233f32b 100644
--- a/src/inkscape-application.cpp
+++ b/src/inkscape-application.cpp
@@ -436,7 +436,11 @@ template<class T>
ConcreteInkscapeApplication<T>::ConcreteInkscapeApplication()
: T("org.inkscape.application.with_gui",
Gio::APPLICATION_HANDLES_OPEN | // Use default file opening.
- Gio::APPLICATION_NON_UNIQUE ) // Allows different instances of Inkscape to run at same time.
+ Gio::APPLICATION_CAN_OVERRIDE_APP_ID ) // Allows different instances of
+ // Inkscape to run at same time using
+ // --gapplication-app-id (useful for
+ // debugging different versions of
+ // Inkscape).
, InkscapeApplication()
{